app_name = "EU Diktátor 2020"

what_is_your_name = "Jak se jmenuješ? "
what_is_your_gender = "Jakého seš pohlaví? "

proceed = "Pokračovat..."

period = "Období: {} {}"
budget = "Rozpočet {}: {:,} EUR, rozdíl příjmů a výdajů: {:,} EUR, dluh: {:,} EUR"
membership_satisfaction = "Spokojenost členských států: {:.2f} %"

intro = """
Ahoj {},
gratuluji - právě si se {} šéfem Evropské komise. Tvá síla a možnosti jsou prakticky neomezené.
Vládneš {} členským zemím a tvým úkolem je udržet je co nejdéle v EU.
"""

gender_dict = {
    "stal": {
        "m": "stal",
        "f": "stala",
        "n": "stalo"
    }
}

options = "Možnosti:"
higher_power_event = "Mimořádná událost"
higher_power_events = "Mimořádné události: {}"
